ParseEntity class

Constructors

ParseEntity({String? from = 'Json', String? to = 'Json', String keyType = 'snake_case', bool copyWith = true, bool copyWithData = true})
const

Properties

copyWith bool
final
copyWithData bool
final
from String?
final
hashCode int
The hash code for this object.
no setterinherited
keyType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited