ParseValue<T> class
Constructors
- ParseValue({String? key, bool raw = false, T? defaultValue, ParseIgnore ignore = ParseIgnore.none, dynamic keyConverter, dynamic converter, dynamic entryConverter, dynamic fromConverter, dynamic toConverter})
-
const
Properties
- converter → dynamic
-
final
- defaultValue → T?
-
final
- entryConverter → dynamic
-
final
- fromConverter → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignore → ParseIgnore
-
final
- key → String?
-
final
- keyConverter → dynamic
-
final
- raw → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toConverter → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited